Commit 266c0023dad8e71deaf751828b90b90201e809ff

Ryan C. Gordon 2014-09-17T14:47:42

Fixed haptic documentation typos (thanks, Elias!). Partially fixes Bugzilla #2701.

diff --git a/include/SDL_haptic.h b/include/SDL_haptic.h
index 827aa24..9c4b427 100644
--- a/include/SDL_haptic.h
+++ b/include/SDL_haptic.h
@@ -492,7 +492,7 @@ typedef struct SDL_HapticConstant
  *  over time.  The type determines the shape of the wave and the parameters
  *  determine the dimensions of the wave.
  *
  *  Phase is given by hundredth of a cycle meaning that giving the phase a value
  *  of 9000 will displace it 25% of its period.  Here are sample values:
  *   -     0: No phase displacement.
  *   -  9000: Displaced 25% of its period.
@@ -555,7 +555,7 @@ typedef struct SDL_HapticPeriodic
     Uint16 period;      /**< Period of the wave. */
     Sint16 magnitude;   /**< Peak value. */
     Sint16 offset;      /**< Mean value of the wave. */
-    Uint16 phase;       /**< Horizontal shift given by hundredth of a cycle. */
+    Uint16 phase;       /**< Horizontal shift given by hundredth of a degree. */
 
     /* Envelope */
     Uint16 attack_length;   /**< Duration of the attack. */
@@ -492,7 +492,7 @@ typedef struct SDL_HapticConstant
  *  determine the dimensions of the wave.
  *
- *  Phase is given by hundredth of a cycle meaning that giving the phase a value
+ *  Phase is given by hundredth of a degree meaning that giving the phase a value
  *  of 9000 will displace it 25% of its period.  Here are sample values:
  *   -     0: No phase displacement.